% NMFvisualizer main file
%
%	This function visualizes an NMF optimization and outputs mp4 movie file.
%
%   This funcntion is coded by Daichi Kitamura on 25 Feb. 2016.
%
%   see also
%   http://d-kitamura.sakura.ne.jp/index.html

clear;
close all;
config;
s = RandStream('mt19937ar','Seed',seed);
RandStream.setGlobalStream(s)

% Make output directory
if ~isdir( outputDirName )
    mkdir( outputDirName );
end

% Set input file name
inputName = sprintf( '%s/%s', inputDirName, inputFileName );

% Read input wav file
[ inputWave, fs ] = audioread( inputName );

% Short time Fourier transform with rectangle window
[inputSpectrogram, window] = STFT( inputWave, fftSize, shiftSize );

% Show power spectrogram of input signal
showSpect(inputSpectrogram, fs/2, shiftSize);

% Obtain angles and powers of the input spectrograms
inputSpectrogramAngle = angle( inputSpectrogram );
inputSpectrogramPower = abs( inputSpectrogram ).^2;

% NMF based on beta-divergence
[ A, B ] = betaNMFvisualizer( inputSpectrogramPower, fs, shiftSize, beta, nb, iteration );

% Reconstruct spectrogram
outputSpectrogram = sqrt(A*B) .* exp( 1i * inputSpectrogramAngle );

% Inverse short time Fourier transform with hanning window
outputWave = invSTFT( outputSpectrogram, shiftSize, window );

% Trancate redundant signal tail produced by zero padding in STFT
outputWave = outputWave(1:size(inputWave,1),:);

% Write wave files
outputName = sprintf( '%s/%s', outputDirName, outputFileName );
audiowrite( outputName, outputWave, fs );
fprintf('Output comprete.\n');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% EOF %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%