function [ graph, f, t ] = showSpect( S, fs, shift )
%
% Corded by D. Kitamura (d-kitamura@nii.ac.jp) on 2 Jan. 2016.
%
% This function shows power spectrogram from time-frequency matrix.
%
% see also
% http://d-kitamura.sakura.ne.jp/index.html
%
% [syntax]
%   [Graph, Faxis, Taxis] = showSpect(S)
%   [Graph, Faxis, Taxis] = showSpect(S, Fs, Lshift)
%
% [inputs]
%          S: STFT matrix (I x J, complex is supported)
%         fs: sampling frequnecy
%      shift: length of window shift
%
% [outputs]
%      graph: graphics handle
%          f: frequency axis (1 x I)
%          t: time axis (1 x J)

% Check errors and set default values
[I, J] = size(S);
if isreal(S) == false
    S = real(S.*conj(S)); % Calculate power spectrogram
end
if (nargin < 2)
    f = 1:I;
    t = 1:J;
elseif (nargin < 3)
    error('Too few input arguments.\n');
else
    f = fs/I : fs/I : fs;
    t = shift/fs : shift/fs : (shift/fs)*J;
end

graph = figure;
surf(t,f,10*log10(S),'edgecolor','none');
axis tight;
view(0,90);
set(gca,'FontName','Times','FontSize',16);
xlabel('Time [s]','FontName','Arial','FontSize',16);
ylabel('Freqency [Hz]','FontName','Arial','FontSize',16);
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% EOF %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%